import * as logger from './log'
import { mqttHandler } from './MqttDispatcher'
import { AItem } from './AItem'


export class M433SwitchItem extends AItem {
    private offCode: string
    private onCode: string
    private oldState: string|undefined
    private state: string
    private actionTopic: string
    private stateFeedbackTopic: string
    private stateTopic: string

    constructor(floor: string, room: string, item: string, onCode: string, offCode: string) {
        super(floor, room, item)
        this.stateTopic = `${this.topicFirstPart}/state`
        this.subscribeTopics = [this.stateTopic]
        this.stateFeedbackTopic = `${this.topicFirstPart}/state/feedback`
        this.actionTopic = 'IoT/Mqtt433Gateway/Message'
        this.state = 'OFF'
        this.oldState = undefined
        this.onCode = onCode
        this.offCode = offCode
    }

    processMessage(topic: string, payload: string) {
        this.state = payload;
        mqttHandler.send(this.stateFeedbackTopic, this.state);
        if (this.state != this.oldState) {                
            if (this.state == 'ON') {
                mqttHandler.send(this.actionTopic, this.onCode);
            } else {
                mqttHandler.send(this.actionTopic, this.offCode);
            }
            this.oldState = this.state;
        }
    }
}

